<template>
    <div class="app-container">
        <div style="margin-bottom: 10px">
            <el-button
                type="primary"
                plain
                icon="Plus"
                @click="openDialog('add',{})"
            >新增</el-button>
        </div>
        <!-- 表格数据 -->
        <el-table v-loading="loading" :data="dataList" :border="true" row-key="id">
            <el-table-column label="地区"  align="center">
                <template #default="scope">
                    <span>{{scope.row.name}}</span>

                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
                <template #default="scope">
                    <el-button link type="primary"  @click="openDialog('edit',scope.row)" >编辑</el-button>
                    <el-button link type="danger"  @click="handleDelete(scope.row)" >删除</el-button>
                </template>
            </el-table-column>
        </el-table>
        <area-dialog ref="areaRef" @getList="getList"></area-dialog>
    </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import areaDialog from "./components/areaDialog.vue"
import {delArea, getArea} from "@/api/backManage/area";
import {getDictList} from "@/api/backManage/evaluate";
import {delMonitor} from "@/api/sysUsers";
const { proxy } = getCurrentInstance();
const loading = ref(false);
const areaRef = ref();
const cityList = ref([])
const data = reactive({
    queryParams: {
        pageNum: 1,
        pageSize: 10,
    },
    total: 0,
    dataList: [
    ]
});

const { queryParams, total, dataList } = toRefs(data);

//页面加载
onMounted(() => {
    getList();
});
const getList = async () => {
    loading.value = true;
    const res = await getArea();
    if(res.code === 200){
        dataList.value = res.data
        cityList.value = res.data.map(item => {
            return {
                id: item.id,
                name: item.name,
                parentId: item.parentId,
                regionType: item.regionType,
                sort: item.sort

            }
        })
    }else{
        ElMessage.warning(res.message)
    }
    loading.value = false;
}

const openDialog = (type, value) => {
    areaRef.value.openDialog(type, value,cityList.value);
}

/** 重置新增的表单以及其他数据  */
function reset() {
    proxy.resetForm("roleRef");
}
const handleDelete = (val) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        })
        .then( async() => {
            const res = await delArea(val)
            if(res.code == 200){
                ElMessage.success('数据删除成功')
                getList()
            }else{
                ElMessage.warning(res.message)
            }
        })
}

</script>
